@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,11 +16,11 @@
  */
 package org.apache.commons.pool2.proxy;
 
-public class TestProxiedKeyedObjectPoolWithCglibProxy extends
-        BaseTestProxiedKeyedObjectPool {
+class TestProxiedKeyedObjectPoolWithCglibProxy extends
+        AbstractTestProxiedKeyedObjectPool {
 
     @Override
     protected ProxySource<TestObject> getproxySource() {
-        return new CglibProxySource<TestObject>(TestObject.class);
+        return new CglibProxySource<>(TestObject.class);
     }
-}
\ No newline at end of file
+}
